@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2007 Alon Bar-Lev <alon.barlev@gmail.com>
+ * Copyright (c) 2005-2008 Alon Bar-Lev <alon.barlev@gmail.com>
  * All rights reserved.
  *
  * This software is available to you under a choice of one of two
@@ -78,6 +78,9 @@
 #if !defined(CRYPT_VERIFY_CERT_SIGN_ISSUER_CERT)
 #define CRYPT_VERIFY_CERT_SIGN_ISSUER_CERT	0x02
 #endif
+#if !defined(CERT_NAME_STR_REVERSE_FLAG)
+#define CERT_NAME_STR_REVERSE_FLAG		0x02000000
+#endif
 
 #endif
 
