@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2007 Alon Bar-Lev <alon.barlev@gmail.com>
+ * Copyright (c) 2005-2008 Alon Bar-Lev <alon.barlev@gmail.com>
  * All rights reserved.
  *
  * This software is available to you under a choice of one of two
@@ -264,7 +264,7 @@ cleanup:
 		pkcs11h_getMessage (rv)
 	);
 
-	return rv == CKR_OK ? tlen : -1; 
+	return rv == CKR_OK ? (int)tlen : -1; 
 }
 
 #if OPENSSL_VERSION_NUMBER < 0x00907000L
